
__version__ = (0, 5, 7, '')
__versionstr__ = '0.5.7'

from djangosanetesting.cases import *
from djangosanetesting.testrunner import *
